<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Modalità aereo abilitata</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Modalità aereo disabilitata</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Disattiva</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Attiva</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modalità aereo</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Gestione modalità aereo</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modalità aereo</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Impostazioni Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Disattivato</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Disattiva</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Attiva</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Impostazioni Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connesso</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Connessione in corso...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Disattivato</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Connesso a %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connesso</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Spento</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Luminosità</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Impostazioni schermo</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Impostazioni schermo</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Luminosità</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Dom</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Lun</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Mer</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Gio</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Ven</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Sab</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Aggiungi un layout della Tastiera</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Orologio</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Formato 12 ore</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Formato 24 ore</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Impostazioni orarie</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Lunedì</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martedì</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mercoledì</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Giovedì</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Venerdì</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sabato</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domenica</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>lunedì</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>martedì</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>mercoledì</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>giovedì</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>venerdì</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sabato</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>domenica</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Modalità DND</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Impostazioni modalità DND</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Disattiva</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Attiva</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Modalità DND Attiva</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Modalità DND Disattivata</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Modalità DND</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Comfort visivo</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Comfort visivo attivato</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Comfort visivo disattivato</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Visual effect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Fashion</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efficient</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Sopra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Sotto</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mostra sempre</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Lascia nascosta</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Nascondi automaticamente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Impostazioni Dock</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Nessun messaggio</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Impostazioni notifiche</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notifiche</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Disabilita modalità Non Disturbare</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Attiva modalità Non Disturbare</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Notifiche</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Tastiera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Alte prestazioni</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Bilanciato</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Risparmio energetico</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Impostazioni Alimentazione</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Autonomia %1, %2 min. rimanenti</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Autonomia %1, %2 ore e %3 min. rimanenti</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Carica %1, %2 min. per la carica completa</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Carica %1, %2 ore e %3 min. per la carica completa</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Carica %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>In carica %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Carica %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Carica completa, capacità %1</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Capacità %1, non in carica</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Batteria</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not charging</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fully charged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ibernazione</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocca</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Logout</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Impostazioni Alimentazione</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Aggiorna e spegni</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Aggiorna e riavvia</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch user</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>y</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>m</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>d</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Feb</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Apr</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>May</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jun</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jul</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Aug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sept</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Oct</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nov</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sunday</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Impostazioni audio</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Audio</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Abilita suoni</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Muto</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Impostazioni audio</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Nessun dispositivo di output</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
</TS>